@@ -32,8 +32,9 @@ class ToneGenerator:
                           'F': [frequencyR[3], frequencyC[2]]
                           }
 
-    def __init__(self, duration=100):
+    def __init__(self, duration=100, pause=500):
         self.duration = duration
+        self.pause = pause
 
     @staticmethod
     def hex_encode(text_to_encode):
@@ -62,15 +63,24 @@ class ToneGenerator:
             f.writeframes(struct.pack('i', i))
         f.close()
 
-    def generate_tone(self, f1, f2, _duration_in_ms):
+    def _get_silence(self, duration_in_ms=None):
+        if duration_in_ms is None:
+            duration_in_ms = self.pause
+        number_of_samples = int(self.SAMPLE_RATE * duration_in_ms / 1000)
+        result = list()
+        for i in range(number_of_samples):
+            result.append(0)
+        return result
+
+    def generate_tone(self, f1, f2, duration_in_ms):
         """
         Generates a single value representing a sample of two combined frequencies.
         :param f1:
         :param f2:
-        :param _duration_in_ms:
+        :param duration_in_ms:
         :return:
         """
-        number_of_samples = int(self.SAMPLE_RATE * _duration_in_ms / 1000)
+        number_of_samples = int(self.SAMPLE_RATE * duration_in_ms / 1000)
         scale = 32767  # signed int / 2
 
         result = list()
@@ -78,7 +88,7 @@ class ToneGenerator:
             p = i * 1.0 / self.SAMPLE_RATE
             result.append(int((math.sin(p * f1 * math.pi * 2) +
                                math.sin(p * f2 * math.pi * 2)) / 2 * scale))
-        return result
+        return result + self._get_silence()
 
     def encode_to_wave(self, text_to_encode, file_path):
         hex_encoded = self.hex_encode(text_to_encode)
